package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.system.domain.UserInfo;
import com.ruoyi.system.domain.UserInfoOne;

/**
 * 导入人员信息Service接口
 * 
 * @author ruoyi
 * @date 2022-08-11
 */
public interface IUserInfoService
{
    /**
     * 查询导入人员信息
     * 
     * @param id 导入人员信息主键
     * @return 导入人员信息
     */
    public UserInfo selectUserInfoById(Long id);

    /**
     * 查询导入人员信息列表
     * 
     * @param userInfo 导入人员信息
     * @return 导入人员信息集合
     */
    public List<UserInfo> selectUserInfoList(UserInfo userInfo);

    /**
     * 新增导入人员信息
     * 
     * @param userInfo 导入人员信息
     * @return 结果
     */
    public int insertUserInfo(UserInfo userInfo);

    /**
     * 修改导入人员信息
     * 
     * @param userInfo 导入人员信息
     * @return 结果
     */
    public int updateUserInfo(UserInfo userInfo);

    /**
     * 批量删除导入人员信息
     * 
     * @param ids 需要删除的导入人员信息主键集合
     * @return 结果
     */
    public int deleteUserInfoByIds(Long[] ids);

    /**
     * 删除导入人员信息信息
     * 
     * @param id 导入人员信息主键
     * @return 结果
     */
    public int deleteUserInfoById(Long id);

    String importUser(List<UserInfo> userList, String jobStyle, String focusCrowdStyle, String detectionNumber, String detectionScope, String startTime, String endTime, SysUser user) throws Exception;

    AjaxResult oneDate(UserInfo userInfo) throws Exception;

    List<UserInfoOne> oneDateList(UserInfoOne userInfoOne);

    int deleteUserInfoOneByIds(Long[] ids);

    String date(UserInfo userInfo,SysUser user) throws Exception;
}
